@@ -34,7 +34,9 @@ class CircuitMaintenanceView(generic.ObjectView):
         """Extend content of detailed view for Circuit Maintenance."""
         maintenance_note = models.Note.objects.filter(maintenance=instance)
         circuits = models.CircuitImpact.objects.filter(maintenance=instance)
-        parsednotification = models.ParsedNotification.objects.filter(maintenance=instance)
+        parsednotification = models.ParsedNotification.objects.filter(maintenance=instance).order_by(
+            "-raw_notification__date"
+        )
 
         return {
             "circuits": circuits,
